"""SCons.Tool.swig

Tool-specific initialization for swig.

There normally shouldn't be any need to import this module directly.
It will usually be imported through the generic SCons.Tool.Tool()
selection method.

"""

#
# Copyright (c) 2001, 2002, 2003, 2004 The SCons Foundation
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

__revision__ = "/home/scons/scons/branch.0/baseline/src/engine/SCons/Tool/swig.py 0.96.1.D001 2004/08/23 09:55:29 knight"

import SCons.Defaults
import SCons.Tool
import SCons.Util
import re

SwigAction = SCons.Action.Action('$SWIGCOM', '$SWIGCOMSTR')

## Implicit Dependency checker for %include statements.
include_re = re.compile(r'^(?: )(.*)(?: )\\', re.M)

def ifile_scan(node, env, path, arg):
	myenv    = env.Copy()
	command  = SCons.Action.CommandAction(myenv['SWIGCOM']).strfunction(None,node,myenv)
	command  = command.replace('-o ', '-M ')
	import os
	return [env.File(x) for x in	include_re.findall(os.popen(command).read())]
	

IScanner = SCons.Scanner.Scanner( name = 'ifile',
	function = ifile_scan,
	argument = None,
	skeys = ['.i'] )

def swigSuffixEmitter(env, source):
	if '-c++' in SCons.Util.CLVar(env.subst("$SWIGFLAGS")):
		return '$SWIGCXXFILESUFFIX'
	else:
		return '$SWIGCFILESUFFIX'
   
def generate(env):
	"""Add Builders and construction variables for swig to an Environment."""

	env.Append( SCANNERS = IScanner )
	
	c_file, cxx_file = SCons.Tool.createCFileBuilders(env)
	
	c_file.suffix['.i'] = swigSuffixEmitter
	cxx_file.suffix['.i'] = swigSuffixEmitter
	
	c_file.add_action('.i', SwigAction)
	cxx_file.add_action('.i', SwigAction)
	
	env['SWIG']              = 'swig'
	env['SWIGFLAGS']         = SCons.Util.CLVar('')
	env['SWIGCFILESUFFIX']   = '_wrap$CFILESUFFIX'
	env['SWIGCXXFILESUFFIX'] = '_wrap$CXXFILESUFFIX'
	env['SWIGINCLUDEPATH']   = '.'
	env['SWIGCOM']           = '$SWIG $SWIGFLAGS -I$SWIGINCLUDEPATH -o $TARGET $SOURCES'

def exists(env):
	return env.Detect('swig')
