/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Toolkit;
import java.util.prefs.Preferences;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.JSplitPane;
import javax.swing.JTabbedPane;
import javax.swing.JTextField;
import javax.swing.JToggleButton;
import javax.swing.SpinnerNumberModel;
import javax.swing.UIManager;
import javax.swing.text.NumberFormatter;

import edu.teco.particles.pComponent.Console;
import edu.teco.particles.pComponent.Scanner;
import edu.teco.particles.pComponent.Scope;
import edu.teco.particles.pComponent.Sender;
import edu.teco.particles.pComponent.SocketThread;
import edu.teco.particles.pComponent.scanner.ScanNetworkAction;
import edu.teco.particles.pComponent.util.PropertyPanel;

/**
 * This Class was created with the Visual Editor of the Eclipse Platform.
 */
public class Analyzer extends JFrame
{
  /**
   * loads the Wrapper Library.
   */
  static
  {
    System.loadLibrary("particleJava");
  }

  protected Preferences      _prefs;

  protected final String     RECV_PORT         = "recv_port";

  protected final String     SEND_PORT         = "send_port";

  protected final String     UPDATE_DELAY      = "update_delay";

  private javax.swing.JPanel jContentPane      = null;

  private JSplitPane         jSplitPane        = null;

  private JPanel             jPanel            = null;

  private JTabbedPane        jTabbedPane       = null;

  private Console            console           = null;

  private Scope              scope             = null;

  private JLabel             jLabel            = null;

  private JLabel             jLabel1           = null;

  private JToggleButton      startStopButton     = null;          // @jve:decl-index=0:visual-constraint="-70,163"

  private JButton            jButton           = null;

  private SocketThread       socketThread      = null;          // @jve:decl-index=0:

  private PropertyPanel      propertyPanel     = null;

  private SocketThread       unfilteredSocketThread     = null;          // @jve:decl-index=0:

  private JPanel             scopePanel        = null;

  private PropertyPanel      propertyPanel11   = null;

  private ScanNetworkAction  scanNetworkAction = null;          // @jve:decl-index=0:

  private JPanel             jPanel1           = null;

  private JLabel             jLabel2           = null;

  private JSpinner           recvPortSpinner   = null;

  private JLabel             jLabel3           = null;

  private JSpinner           sendPortSpinner   = null;

  private JLabel             jLabel4           = null;

  private JSpinner           updateDelaySpinner = null;

  private JButton            jButton2          = null;

  private JPanel             jPanel2           = null;

  private Sender             sender            = null;

  private PropertyPanel      propertyPanel1    = null;

  private Scanner            scanner1          = null;

  /**
   * This method initializes jSplitPane
   * 
   * @return javax.swing.JSplitPane
   */
  private JSplitPane getJSplitPane()
  {
    if (jSplitPane == null)
    {
      jSplitPane = new JSplitPane();
      jSplitPane.setDividerSize(5);
      jSplitPane.setOneTouchExpandable(true);
      jSplitPane.setResizeWeight(0.8D);
      jSplitPane.setRightComponent(getJPanel());
      jSplitPane.setLeftComponent(getJTabbedPane());
    }
    return jSplitPane;
  }

  /**
   * This method initializes jPanel
   * 
   * @return javax.swing.JPanel
   */
  private JPanel getJPanel()
  {
    if (jPanel == null)
    {
      GridBagConstraints gridBagConstraints2 = new GridBagConstraints();
      gridBagConstraints2.gridx = 0;
      gridBagConstraints2.gridwidth = 2;
      gridBagConstraints2.fill = java.awt.GridBagConstraints.HORIZONTAL;
      gridBagConstraints2.insets = new java.awt.Insets(0,5,0,5);
      gridBagConstraints2.gridy = 7;
      GridBagConstraints gridBagConstraints = new GridBagConstraints();
      gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
      gridBagConstraints.gridy = 6;
      gridBagConstraints.weightx = 1.0;
      gridBagConstraints.weighty = 1.0;
      gridBagConstraints.gridwidth = 2;
      gridBagConstraints.insets = new java.awt.Insets(5,5,5,0);
      gridBagConstraints.gridx = 0;
      GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
      jLabel1 = new JLabel();
      jLabel = new JLabel();
      GridBagConstraints gridBagConstraints14 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints15 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints17 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints18 = new GridBagConstraints();
      jPanel = new JPanel();
      jPanel.setLayout(new GridBagLayout());
      jPanel.setComponentOrientation(java.awt.ComponentOrientation.UNKNOWN);
      jPanel.setBorder(new javax.swing.border.SoftBevelBorder(
          javax.swing.border.SoftBevelBorder.RAISED));
      jLabel.setText("");
      jLabel.setIcon(new ImageIcon(getClass()
          .getResource("/images/logoneu.gif")));
      gridBagConstraints14.anchor = java.awt.GridBagConstraints.NORTHEAST;
      gridBagConstraints14.weightx = 0.0D;
      gridBagConstraints14.weighty = 0.0D;
      gridBagConstraints14.gridx = 0;
      gridBagConstraints14.gridy = 0;
      gridBagConstraints14.insets = new java.awt.Insets(5, 0, 0, 5);
      gridBagConstraints14.gridwidth = 2;
      gridBagConstraints15.gridx = 0;
      gridBagConstraints15.gridy = 1;
      gridBagConstraints15.insets = new java.awt.Insets(5, 0, 0, 5);
      gridBagConstraints15.anchor = java.awt.GridBagConstraints.EAST;
      gridBagConstraints15.gridwidth = 2;
      jLabel1.setText("University of Karlsruhe");
      jLabel1.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
      jLabel1.setHorizontalTextPosition(javax.swing.SwingConstants.RIGHT);
      gridBagConstraints17.gridx = 1;
      gridBagConstraints17.gridy = 3;
      gridBagConstraints17.anchor = java.awt.GridBagConstraints.EAST;
      gridBagConstraints17.insets = new java.awt.Insets(5, 0, 0, 5);
      gridBagConstraints18.gridx = 0;
      gridBagConstraints18.gridy = 3;
      gridBagConstraints18.insets = new java.awt.Insets(5, 10, 0, 5);
      gridBagConstraints18.anchor = java.awt.GridBagConstraints.EAST;
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.insets = new java.awt.Insets(5,0,0,0);
      gridBagConstraints1.gridy = 5;
      gridBagConstraints1.gridwidth = 2;
      jPanel.add(jLabel, gridBagConstraints14);
      jPanel.add(jLabel1, gridBagConstraints15);
      jPanel.add(getJButton(), gridBagConstraints17);
      jPanel.add(getStartStopButton(), gridBagConstraints18);
      jPanel.add(getJButton2(), gridBagConstraints1);
      jPanel.add(getScanner1(), gridBagConstraints);
      jPanel.add(getJPanel1(), gridBagConstraints2);
    }
    return jPanel;
  }

  /**
   * This method initializes jTabbedPane
   * 
   * @return javax.swing.JTabbedPane
   */
  private JTabbedPane getJTabbedPane()
  {
    if (jTabbedPane == null)
    {
      jTabbedPane = new JTabbedPane();
      jTabbedPane.addTab("Console", null, getConsole(), null);
      jTabbedPane.addTab("Scope", null, getScopePanel(), null);
      jTabbedPane.addTab("SendToParticle", null, getJPanel2(), null);
    }
    return jTabbedPane;
  }

  /**
   * This method initializes console
   * 
   * @return edu.teco.particles.pComponent.console.Console
   */
  private Console getConsole()
  {
    if (console == null)
    {
      console = new Console();
      console.setShowLocation(false);
      console.add(getPropertyPanel(), java.awt.BorderLayout.NORTH);
      
      console.setSocket(getFilteredSocketThread());
    }
    return console;
  }

  /**
   * This method initializes scope
   * 
   * @return edu.teco.particles.pComponent.scope.Scope
   */
  private Scope getScope()
  {
    if (scope == null)
    {
      scope = new Scope();
      scope.setSocket(getFilteredSocketThread());
    }
    return scope;
  }

  /**
   * This method initializes startStopButton
   * 
   * @return javax.swing.JToggleButton
   */
  private JToggleButton getStartStopButton()
  {
    if (startStopButton == null)
    {
      startStopButton = new JToggleButton();
      startStopButton.setText("Start");
      startStopButton.addItemListener(new java.awt.event.ItemListener() {
        public void itemStateChanged(java.awt.event.ItemEvent e)
        {
          if (startStopButton.isSelected())
          {
            startStopButton.setText("Stop");
            getFilteredSocketThread().setReceiving(true);
          }
          else
          {
            startStopButton.setText("Start");
            getFilteredSocketThread().setReceiving(false);
          }
        }
      });
    }
    return startStopButton;
  }

  /**
   * This method initializes jButton
   * 
   * @return javax.swing.JButton
   */
  private JButton getJButton()
  {
    if (jButton == null)
    {
      jButton = new JButton();
      jButton.setText("Clear");
      jButton.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent e)
        {
          getConsole().clear();
          getScope().clear();
        }
      });
    }
    return jButton;
  }

  /**
   * This method initializes socketThread
   * 
   * @return edu.teco.particles.pComponent.socketThread.SocketThread
   */
  private SocketThread getFilteredSocketThread()
  {
    if (socketThread == null)
    {
      socketThread = new SocketThread();
      socketThread.setRecvPort(_prefs.getInt(RECV_PORT, 5555));
      socketThread.setReceiving(false);
      socketThread.setUpdateDelay(40);
    }
    return socketThread;
  }

  /**
   * This method initializes propertyPanel
   * 
   * @return edu.teco.particles.pComponent.util.PropertyPanel
   */
  private PropertyPanel getPropertyPanel()
  {
    if (propertyPanel == null)
    {
      propertyPanel = new PropertyPanel();
      propertyPanel.setBean(getConsole());
    }
    return propertyPanel;
  }

  /**
   * This method initializes unfilteredSocketThread
   * 
   * @return edu.teco.particles.pComponent.socketThread.SocketThread
   */
  private SocketThread getUnfilteredSocketThread()
  {
    if (unfilteredSocketThread == null)
    {
      unfilteredSocketThread = new SocketThread();
      unfilteredSocketThread.setRecvPort(_prefs.getInt(RECV_PORT, 5555));
      unfilteredSocketThread.setUpdateDelay(200);
      unfilteredSocketThread.setReceiving(true);
    }
    return unfilteredSocketThread;
  }

  /**
   * This method initializes jPanel1
   * 
   * @return javax.swing.JPanel
   */
  private JPanel getScopePanel()
  {
    if (scopePanel == null)
    {
      scopePanel = new JPanel();
      scopePanel.setLayout(new BorderLayout());
      scopePanel.add(getScope(), java.awt.BorderLayout.CENTER);
      scopePanel.add(getPropertyPanel11(), java.awt.BorderLayout.NORTH);
    }
    return scopePanel;
  }

  /**
   * This method initializes propertyPanel11
   * 
   * @return edu.teco.particles.pComponent.util.PropertyPanel
   */
  private PropertyPanel getPropertyPanel11()
  {
    if (propertyPanel11 == null)
    {
      propertyPanel11 = new PropertyPanel();
      propertyPanel11.setBean(getScope());
    }
    return propertyPanel11;
  }

  /**
   * This method initializes scanNetworkAction
   * 
   * @return edu.teco.particles.pComponent.scanner.ScanNetworkAction
   */
  private ScanNetworkAction getScanNetworkAction()
  {
    if (scanNetworkAction == null)
    {
      scanNetworkAction = new ScanNetworkAction();
      scanNetworkAction.setSocket(getFilteredSocketThread());
    }
    return scanNetworkAction;
  }

  /**
   * This method initializes jPanel1
   * 
   * @return javax.swing.JPanel
   */
  private JPanel getJPanel1()
  {
    if (jPanel1 == null)
    {
      jLabel4 = new JLabel();
      jLabel3 = new JLabel();
      jLabel2 = new JLabel();
      GridBagConstraints gridBagConstraints10 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints11 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints12 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints13 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints141 = new GridBagConstraints();
      GridBagConstraints gridBagConstraints151 = new GridBagConstraints();
      jPanel1 = new JPanel();
      jPanel1.setLayout(new GridBagLayout());
      jPanel1.setBorder(javax.swing.BorderFactory.createTitledBorder(null,
          "socket Settings",
          javax.swing.border.TitledBorder.DEFAULT_JUSTIFICATION,
          javax.swing.border.TitledBorder.DEFAULT_POSITION, null, null));
      gridBagConstraints10.gridx = 0;
      gridBagConstraints10.gridy = 0;
      gridBagConstraints10.anchor = java.awt.GridBagConstraints.WEST;
      gridBagConstraints10.fill = java.awt.GridBagConstraints.HORIZONTAL;
      jLabel2.setText("receive Port");
      jLabel2.setPreferredSize(new java.awt.Dimension(75, 14));
      gridBagConstraints11.gridx = 1;
      gridBagConstraints11.gridy = 0;
      gridBagConstraints11.anchor = java.awt.GridBagConstraints.EAST;
      gridBagConstraints12.gridx = 0;
      gridBagConstraints12.gridy = 1;
      gridBagConstraints12.anchor = java.awt.GridBagConstraints.WEST;
      gridBagConstraints12.fill = java.awt.GridBagConstraints.HORIZONTAL;
      jLabel3.setText("send Port");
      jLabel3.setPreferredSize(new java.awt.Dimension(75, 14));
      gridBagConstraints13.gridx = 1;
      gridBagConstraints13.gridy = 1;
      gridBagConstraints13.anchor = java.awt.GridBagConstraints.EAST;
      gridBagConstraints141.gridx = 0;
      gridBagConstraints141.gridy = 2;
      gridBagConstraints141.anchor = java.awt.GridBagConstraints.WEST;
      gridBagConstraints141.fill = java.awt.GridBagConstraints.HORIZONTAL;
      jLabel4.setText("update Delay");
      jLabel4.setPreferredSize(new java.awt.Dimension(75, 14));
      gridBagConstraints151.gridx = 1;
      gridBagConstraints151.gridy = 2;
      gridBagConstraints151.anchor = java.awt.GridBagConstraints.EAST;
      jPanel1.add(jLabel2, gridBagConstraints10);
      jPanel1.add(getRecvPortSpinner(), gridBagConstraints11);
      jPanel1.add(jLabel3, gridBagConstraints12);
      jPanel1.add(getSendPortSpinner(), gridBagConstraints13);
      jPanel1.add(jLabel4, gridBagConstraints141);
      jPanel1.add(getUpdateDelaySpinner(), gridBagConstraints151);
    }
    return jPanel1;
  }

  /**
   * This method initializes recvPortSpinner
   * 
   * @return javax.swing.JSpinner
   */
  private JSpinner getRecvPortSpinner()
  {
    if (recvPortSpinner == null)
    {
      recvPortSpinner = new JSpinner();
      recvPortSpinner.setEditor(new JSpinner.NumberEditor(recvPortSpinner, "#####"));
      recvPortSpinner.setPreferredSize(new java.awt.Dimension(62, 20));

      recvPortSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
        public void stateChanged(javax.swing.event.ChangeEvent e)
        {
          try
          {
            getFilteredSocketThread().setRecvPort((Integer) recvPortSpinner.getValue());
            getUnfilteredSocketThread().setRecvPort((Integer) recvPortSpinner.getValue());
            _prefs.putInt(RECV_PORT, (Integer) recvPortSpinner.getValue());
            ((JSpinner.NumberEditor) recvPortSpinner.getEditor()).
            getTextField().setBackground(UIManager.getColor("Textfield.background"));
          }
          catch (Exception e1)
          {
            ((JSpinner.NumberEditor) recvPortSpinner.getEditor()).
            getTextField().setBackground(Color.RED); 
          }
        }
      });
      
      recvPortSpinner.setValue(
          _prefs.getInt(RECV_PORT, getFilteredSocketThread().getRecvPort()));
    }
    return recvPortSpinner;
  }

  /**
   * This method initializes sendPortSpinner
   * 
   * @return javax.swing.JSpinner
   */
  private JSpinner getSendPortSpinner()
  {
    if (sendPortSpinner == null)
    {
      sendPortSpinner = new JSpinner();
      sendPortSpinner.setEditor(new JSpinner.NumberEditor(sendPortSpinner, "#####"));
      sendPortSpinner.setPreferredSize(new java.awt.Dimension(62, 20));

      sendPortSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
        public void stateChanged(javax.swing.event.ChangeEvent e)
        {
          try
          {
            getFilteredSocketThread().setSendPort((Integer) sendPortSpinner.getValue());
            getUnfilteredSocketThread().setSendPort((Integer) sendPortSpinner.getValue());
            _prefs.putInt(SEND_PORT, (Integer) sendPortSpinner.getValue());
            ((JSpinner.NumberEditor) sendPortSpinner.getEditor()).getTextField()
            .setBackground(UIManager.getColor("Textfield.background"));
          }
          catch (Exception e1)
          {
            ((JSpinner.NumberEditor) sendPortSpinner.getEditor()).getTextField()
            .setBackground(Color.RED);
          }
        }
      });

      sendPortSpinner.setValue(_prefs.getInt(SEND_PORT, getFilteredSocketThread()
          .getRecvPort()));
    }
    return sendPortSpinner;
  }

  /**
   * This method initializes updateDelaySpinner
   * 
   * @return javax.swing.JSpinner
   */
  private JSpinner getUpdateDelaySpinner()
  {
    if (updateDelaySpinner == null)
    {
      updateDelaySpinner = new JSpinner();
      updateDelaySpinner.setEditor(new JSpinner.NumberEditor(updateDelaySpinner, "#####"));
      updateDelaySpinner.setPreferredSize(new java.awt.Dimension(62, 20));
  
      int updateDelay = _prefs.getInt(UPDATE_DELAY, getFilteredSocketThread()
          .getUpdateDelay());
      updateDelaySpinner.setValue(updateDelay);
  
      updateDelaySpinner.addChangeListener(new javax.swing.event.ChangeListener() {
        public void stateChanged(javax.swing.event.ChangeEvent e)
        {
          try
          {
            getFilteredSocketThread().setUpdateDelay((Integer) updateDelaySpinner.getValue());
            getUnfilteredSocketThread().setUpdateDelay((Integer) updateDelaySpinner.getValue());
            _prefs.putInt(UPDATE_DELAY, (Integer) updateDelaySpinner.getValue());
            ((JSpinner.NumberEditor) updateDelaySpinner.getEditor()).
            getTextField().setBackground(UIManager.getColor("Textfield.background"));
          }
          catch (Exception e1)
          {
            ((JSpinner.NumberEditor) updateDelaySpinner.getEditor()).
            getTextField().setBackground(Color.RED);
          }
        }
      });
    }
    return updateDelaySpinner;
  }

  /**
   * This method initializes jButton2
   * 
   * @return javax.swing.JButton
   */
  private JButton getJButton2()
  {
    if (jButton2 == null)
    {
      jButton2 = new JButton();
      jButton2.setAction(getScanNetworkAction());
      jButton2.setText("Scan Network");
    }
    return jButton2;
  }

  /**
   * This method initializes jPanel2
   * 
   * @return javax.swing.JPanel
   */
  private JPanel getJPanel2()
  {
    if (jPanel2 == null)
    {
      jPanel2 = new JPanel();
      jPanel2.setLayout(new BorderLayout());
      jPanel2.add(getSender(), java.awt.BorderLayout.CENTER);
      jPanel2.add(getPropertyPanel1(), java.awt.BorderLayout.NORTH);
    }
    return jPanel2;
  }

  /**
   * This method initializes sender
   * 
   * @return edu.teco.particles.pComponent.sender.Sender
   */
  private Sender getSender()
  {
    if (sender == null)
    {
      sender = new Sender();
      sender.setSocket(getUnfilteredSocketThread());
    }
    return sender;
  }

  /**
   * This method initializes propertyPanel1
   * 
   * @return edu.teco.particles.pComponent.util.PropertyPanel
   */
  private PropertyPanel getPropertyPanel1()
  {
    if (propertyPanel1 == null)
    {
      propertyPanel1 = new PropertyPanel();
      propertyPanel1.setBean(getSender());
    }
    return propertyPanel1;
  }

  /**
   * This method initializes networkMap1
   * 
   * @return edu.teco.particles.pComponent.Scanner
   */
  private Scanner getScanner1()
  {
    if (scanner1 == null)
    {
      scanner1 = new Scanner();
      scanner1.setRecvSocket(getUnfilteredSocketThread());
      scanner1.setFilterSocket(getFilteredSocketThread());
      scanner1.addTreeSelectionListener(getSender());
      scanner1.addTreeSelectionListener(getScope());
    }
    return scanner1;
  }

  public static void main(String[] args)
  {
    new Analyzer();
  }

  /**
   * This is the default constructor
   */
  public Analyzer()
  {
    super();
    _prefs = Preferences.userNodeForPackage(this.getClass());
    initialize();
  }

  /**
   * This method initializes this
   * 
   * @return void
   */
  private void initialize()
  {
    // workaround
    UIManager.put("Textfield.background", new JTextField().getBackground());
    
    this.setMinimumSize(new java.awt.Dimension(200, 200));
    this.setIconImage(Toolkit.getDefaultToolkit().getImage(
        getClass().getResource("/images/logo.gif")));
    this.setDefaultCloseOperation(javax.swing.JFrame.EXIT_ON_CLOSE);
    this.setContentPane(getJContentPane());
    this.setTitle("TeCO Particle Analyzer");
    this.setSize(600, 400);

    this.pack();
    this.setVisible(true);
  }

  /**
   * This method initializes jContentPane
   * 
   * @return javax.swing.JPanel
   */
  private javax.swing.JPanel getJContentPane()
  {
    if (jContentPane == null)
    {
      jContentPane = new javax.swing.JPanel();
      jContentPane.setLayout(new java.awt.BorderLayout());
      jContentPane.add(getJSplitPane(), java.awt.BorderLayout.CENTER);
    }
    return jContentPane;
  }
} // @jve:decl-index=0:
