/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles.pComponent;

import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.beans.SimpleBeanInfo;

/**
 * The BeanInfo for the Console Class. Defines which properties should be shown
 * and which not. This is used so that the PropertyPanel doesn't have to filter
 * the Properties for the Bean it is used on.
 */
public class ConsoleBeanInfo extends SimpleBeanInfo
{
  private final static Class _beanClass = Console.class;

  public PropertyDescriptor[] getPropertyDescriptors()
  {
    try
    {
      PropertyDescriptor showSeqNr = new PropertyDescriptor("showSeqNr",
          _beanClass);

      PropertyDescriptor showLocation = new PropertyDescriptor("showLocation",
          _beanClass);

      PropertyDescriptor showSourceId = new PropertyDescriptor("showSourceId",
          _beanClass);

      PropertyDescriptor showAclTuples = new PropertyDescriptor(
          "showAclTuples", _beanClass);

      PropertyDescriptor showTimeStamp = new PropertyDescriptor(
          "showTimeStamp", _beanClass);

      // PropertyDescriptor socket =
      // new PropertyDescriptor( "socket", _beanClass );

      PropertyDescriptor[] rv = { showSeqNr, showLocation, showSourceId,
          showTimeStamp, showAclTuples };

      return rv;
    }
    catch (IntrospectionException e)
    {
      throw new Error(e.toString());
    }
  }
}
