/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles.pComponent;

import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.beans.SimpleBeanInfo;

/**
 * defines the properties of the Scope Bean.
 */
public class ScopeBeanInfo extends SimpleBeanInfo
{
  private final static Class _beanClass = Scope.class;

  public PropertyDescriptor[] getPropertyDescriptors()
  {
    try
    {
      PropertyDescriptor drawImpulses = new PropertyDescriptor("drawImpulses",
          _beanClass);

      PropertyDescriptor drawContinious = new PropertyDescriptor(
          "DrawContinious", _beanClass);

      PropertyDescriptor Resolution = new PropertyDescriptor("resolution [ms]",
          _beanClass, "getResolution", "setResolution");

      PropertyDescriptor minY = new PropertyDescriptor("minY", _beanClass);

      PropertyDescriptor maxY = new PropertyDescriptor("maxY", _beanClass);

      PropertyDescriptor drawXGrid = new PropertyDescriptor("DrawXGrid",
          _beanClass);

      PropertyDescriptor drawYGrid = new PropertyDescriptor("DrawYGrid",
          _beanClass);

      PropertyDescriptor[] rv = { Resolution, drawImpulses, drawContinious,
          drawXGrid, drawYGrid, minY, maxY };

      return rv;
    }
    catch (IntrospectionException e)
    {
      throw new Error(e.toString());
    }
  }

}
