/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles.pComponent.scope;

import java.awt.Color;
import java.awt.geom.Point2D;
import java.beans.PropertyChangeListener;
import java.util.Iterator;
import java.util.List;

/**
 * a Trace is a Container for the drawn data and its Settings.
 * 
 */
public interface Trace
{

  /**
   * adds a list of points to the trace.
   * 
   * @param points
   *          the list of points to be added.
   */
  public void addPoints(List<Point2D> points);

  /**
   * adds a single point to the trace.
   * 
   * @param point
   *          the point to be added.
   */
  public void addPoint(Point2D point);

  /**
   * convenience methods for adding points.
   * 
   * @param x
   *          the x value of the point
   * @param y
   *          the y value of the point
   */
  public void addPoint(double x, double y);

  /**
   * returns a delta Iterators.
   * 
   * @return iterator with regards to the differnce between x values of points.
   */
  public Iterator deltaIterator(double delta);

  /** adds a new Observers */
  public void addTraceChangeListener(TraceChangeListener obs);

  /** removes the Observer again */
  public void removeTraceChangeListener(TraceChangeListener obs);

  /** clear the chart */
  public void clear();

  /** define a constant to access the color */
  public String COLOR = "Color";

  /**
   * defines the color to draw the trace with.
   * 
   * @return the color of the trace
   */
  public Color getColor();

  /**
   * defines the color to draw the trace with.
   * 
   * @param color
   *          the color to draw the trace with.
   */
  public void setColor(Color color);

  /**
   * the offset is added to the y-values of the points.
   * 
   * @return the y-offset.
   */
  public int getOffset();

  /**
   * the y-offset can be used to correct the y-values by a certain amount. For
   * example an offset of 20 means that 20 get added to every y-value.
   * 
   * @param offse
   *          the y-offset.
   */
  public void setOffset(int offset);

  /** set wether the trace is visible or not */
  public void setVisible(boolean state);

  /**
   * @return true if the trace is visible
   */
  public boolean isVisible();

  /** add a property change listener. */
  public void addPropertyChangeListener(PropertyChangeListener list);

  /** remove a property listener */
  public void removePropertyChangeListener(PropertyChangeListener list);
}
