/*
 * Created on 19.04.2005
 *
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

package edu.teco.particles.pComponent.scope;

import java.util.Collection;
import java.util.HashMap;

import edu.teco.particles.libParticle.ParticleSrcId;
import edu.teco.particles.libParticle.ParticleTuple;
import edu.teco.particles.pComponent.util.ParticleContext;

/**
 * A Factory for Traces.
 * 
 * If a Trace for a ParticleContext is already known, this trace is returned.
 * 
 * @author scholl
 */
public class TraceFactory
{

  /** the number of maximum values a TraceLtd must contain */
  protected static int                             MAXVALUES = 20000;

  /** mapping from Context -> DataCurve. */
  protected static HashMap<ParticleContext, Trace> _aclTypeTraceMap;

  /** factory mehtod */
  protected static HashMap<ParticleContext, Trace> _getTraceMap()
  {
    if (_aclTypeTraceMap == null)
    {
      _aclTypeTraceMap = new HashMap<ParticleContext, Trace>();
    }

    return _aclTypeTraceMap;
  }

  /**
   * creates a new Trace.
   * 
   * @param context
   *          the context to create the trace for.
   */
  public static Trace getTrace(ParticleContext context)
  {
    Trace trace = null;

    if (_getTraceMap().containsKey(context))
    {
      trace = _getTraceMap().get(context);
    }
    else
    {
      trace = new TraceLtd(MAXVALUES);
      trace.setColor(context.getColor());
      _getTraceMap().put(context, trace);
    }

    assert (trace != null);
    return trace;
  }

  /**
   * remove a Trace from the Factory.
   * 
   * @param ctx
   *          the context which should be removed.
   */
  public static void removeTrace(ParticleContext ctx)
  {
    _getTraceMap().remove(ctx);
  }

  /**
   * gets all traces in the Factory.
   * 
   * @return a Collection of Traces.
   */
  public static Collection<Trace> getAllTraces()
  {
    return _getTraceMap().values();
  }

  public static Collection<ParticleContext> getAllContextes()
  {
    return _getTraceMap().keySet();
  }

  /**
   * returs the Trace associated with the SrcId and Tuple.
   * 
   * @param srcid
   *          the srcid of the "Trace"
   * @param tuple
   *          the string identification of the tuple
   * @return the associated trace.
   */
  public static Trace getTrace(ParticleSrcId parent, ParticleTuple tuple)
  {
    return getTrace(new ParticleContext(parent, tuple));
  }
}
