/*
 * Created on 09.05.2005
 *
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

package edu.teco.particles.pComponent.sender;

import java.awt.event.ActionEvent;
import java.util.Timer;
import java.util.TimerTask;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import edu.teco.particles.pComponent.SocketThread;

/**
 * Sends an acked packet.
 */
public class AckedSendAction extends DefaultSendAction
{

  protected String _currentName = "Send Acked";

  protected Timer  _delay;

  /**
   * @param sock
   * @param pck
   */
  public AckedSendAction(SocketThread sock, ProxyParticlePacket pck)
  {
    super(sock, pck);
    _delay = new Timer();
  }

  public void actionPerformed(ActionEvent e)
  {
    if (_pck.getDestinationId() == null)
    {
      JOptionPane.showMessageDialog(null, "no srcId was set!");
    }
    else
    {
      try
      {
        _socket.sendAcked(_pck.getPacket(), _pck.getDestinationId());
        firePropertyChange(AbstractAction.NAME, _currentName, "ACK recvd");
        _currentName = "ACK recvd";
      }
      catch (UnknownError ee)
      {
        firePropertyChange(AbstractAction.NAME, _currentName, "No ACK");
        _currentName = "No ACK";
      }

      _pck.setSeqNr((short) (_pck.getSeqNr() + 1));
    }

    // change the Buttons text back in 10 secs
    _delay.schedule(new TimerTask() {
      public void run()
      {
        firePropertyChange(AbstractAction.NAME, _currentName, "Send Acked");
        _currentName = "Send Acked";
      }
    }, 10000);
  }

  /*
   * (non-Javadoc)
   * 
   * @see javax.swing.Action#getValue(java.lang.String)
   */
  public Object getValue(String key)
  {
    if (key.equals(AbstractAction.NAME))
    {
      return _currentName;
    }
    return super.getValue(key);
  }
}
