/*
 * Copyright (c) 2004, 2005
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

package edu.teco.particles.pComponent.test;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import edu.teco.particles.libParticle.ParticlePacket;
import edu.teco.particles.libParticle.ParticleSocket;
import edu.teco.particles.libParticle.ParticleSrcId;
import edu.teco.particles.libParticle.ParticleTuple;
import edu.teco.particles.pComponent.io.DeviceTemplate;
import edu.teco.particles.pComponent.io.ParticleTemplate;
import edu.teco.particles.pComponent.io.TupleTemplate;
import junit.framework.TestCase;

public class TestTupleTemplate extends TestCase
{
  static
  {
    System.loadLibrary("particleJava");
  }

  public void testTypeMatching()
  {
    ParticleTemplate temp = new TupleTemplate("aps");
    ParticlePacket pck = new ParticlePacket();
    pck.add(new ParticleTuple("aps"), 0);

    assertTrue(temp.match(pck));
  }

  public void testNotTypeMatching()
  {
    ParticleTemplate temp = new TupleTemplate("aps");
    ParticlePacket pck = new ParticlePacket();
    pck.add(new ParticleTuple("apx"), 0);

    assertFalse(temp.match(pck));
  }

  public void testNotPayloadMatching()
  {
    ParticleTemplate temp = new TupleTemplate("aps", "0 0");
    ParticlePacket pck = new ParticlePacket();
    pck.add(new ParticleTuple("aps", new short[] { 0, 1 }), 0);

    assertFalse(temp.match(pck));
  }

  public void testPayloadMatching()
  {
    ParticleTemplate temp = new TupleTemplate("aps", "0 0");
    ParticlePacket pck = new ParticlePacket();
    pck.add(new ParticleTuple("aps", new short[] { 0, 0 }), 0);

    assertTrue(temp.match(pck));
  }

  public void testLargePayloadMatching()
  {
    ParticleTemplate temp = new TupleTemplate("aps", "0");
    ParticlePacket pck = new ParticlePacket();
    pck.add(new ParticleTuple("mpt", new short[] {}), 0);
    pck.add(new ParticleTuple("fps", new short[] { 0, 0 }), 0);
    pck.add(new ParticleTuple("aps", new short[] { 0, 3 }), 0);

    assertTrue(temp.match(pck));
    assertEquals(new Short((short) 3), temp.parse());
  }

  public void testCombiningMatching()
  {
    ParticleTemplate t1 = new TupleTemplate("svc", "0 ");
    ParticleTemplate t2 = new TupleTemplate("svc", "1 0");
    DeviceTemplate dt = new DeviceTemplate(new ParticleSocket(5555).getID());
    dt.addChild(t1);
    dt.addChild(t2);

    ParticlePacket pck = new ParticlePacket();
    pck.setSrcId(new ParticleSocket(5555).getID());
    ParticleTuple tup1 = new ParticleTuple("svc", new short[] { 0, 5 });
    ParticleTuple tup2 = new ParticleTuple("svc", new short[] { 1, 0, 6 });
    pck.add(tup1, 0);
    pck.add(tup2, 0);

    assertTrue(dt.match(pck));
    // yes assertEquals is really confused when using autoboxing.
    assertEquals(new Short((short) 5), t1.parse());
    assertEquals(new Short((short) 6), t2.parse());
  }

  public void testCombiningNotMatchingAndNotCallingListeners()
  {
    ParticleTemplate t1 = new TupleTemplate("svc", "0 0");
    ParticleTemplate t2 = new TupleTemplate("svc", "2 0");
    DeviceTemplate dt = new DeviceTemplate(new ParticleSocket(5555).getID());
    dt.addChild(t1);
    dt.addChild(t2);

    ParticlePacket pck = new ParticlePacket();
    ParticleTuple tup1 = new ParticleTuple("svc", new short[] { 0, 0 });
    ParticleTuple tup2 = new ParticleTuple("svc", new short[] { 1, 0 });
    pck.add(tup1, 0);
    pck.add(tup2, 0);

    ActionListener failActionListener = new ActionListener() {
      public void actionPerformed(ActionEvent arg0)
      {
        fail();
      }
    };

    t1.addActionListener(failActionListener);
    t2.addActionListener(failActionListener);
    dt.addActionListener(failActionListener);

    assertFalse(dt.match(pck));
  }
}
