/*
 * Copyright (c) 2004
 * Telecooperation Office (TecO), Universitaet Karlsruhe (TH), Germany.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. Neither the name of the Universitaet Karlsruhe (TH) nor the names
 *    of its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written
 *    permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * @author Philipp Scholl <scholl@teco.edu>
 */

package edu.teco.particles.pComponent.util;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.LayoutManager;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.beans.BeanInfo;
import java.beans.Introspector;
import java.beans.PropertyDescriptor;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.prefs.Preferences;

import javax.swing.BorderFactory;
import javax.swing.JCheckBoxMenuItem;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import javax.swing.UIDefaults;
import javax.swing.UIManager;
import javax.swing.border.TitledBorder;

import sun.swing.UIAction;

/**
 * editor for the Properties of a JavaBean.
 * 
 * currently int, double and boolean properties are supported. Also handles the
 * persistence of the properties.
 */
public class PropertyPanel extends JPanel
{

  private JLabel jLabel = null;

  /**
   * @param arg0
   * @param arg1
   */
  public PropertyPanel(LayoutManager arg0, boolean arg1)
  {
    super(arg0, arg1);

    initialize();
  }

  /**
   * @param arg0
   */
  public PropertyPanel(LayoutManager arg0)
  {
    super(arg0);
    // TODO Auto-generated constructor stub

    initialize();
  }

  /**
   * @param arg0
   */
  public PropertyPanel(boolean arg0)
  {
    super(arg0);
    // TODO Auto-generated constructor stub

    initialize();
  }

  /**
   * 
   */
  public PropertyPanel()
  {
    super();
    // TODO Auto-generated constructor stub

    initialize();
  }

  /**
   * This method initializes this
   * 
   * @return void
   */
  private void initialize()
  {
    BorderLayout borderLayout1 = new BorderLayout();
    jLabel = new JLabel();
    this.setLayout(borderLayout1);
    this.setSize(300, 20);
    jLabel.setFont(new java.awt.Font("Verdana", java.awt.Font.BOLD, 18));
    borderLayout1.setHgap(5);
    borderLayout1.setVgap(5);
    this.add(jLabel, java.awt.BorderLayout.WEST);
    this.add(getJToolBar(), java.awt.BorderLayout.EAST);
  }

  private Object[] _beans;

  private Class    _beanClass;

  private JToolBar jToolBar = null;

  private JMenu    jMenu    = null;

  public void setBeans(Object[] beans)
  {
    _beans = beans;
    for (Object bean : _beans)
    {
      if (_beanClass != null) assert (bean.getClass().equals(_beanClass));

      _beanClass = bean.getClass();

      Preferences prefs = Preferences.userNodeForPackage(_beanClass);
      for (PropertyDescriptor descriptor : _getPropertyDescriptors(_getBeanInfo(_beanClass)))
      {
        if (descriptor.getPropertyType().equals(boolean.class))
        {
          boolean value = prefs.getBoolean(descriptor.getName(),
              (Boolean) _readProperty(descriptor, bean));
          try
          {
            _writeProperty(descriptor, value, bean);
          }
          catch (Exception e)
          { /*ignore*/ }
          JCheckBoxMenuItem item = _getCheckBoxItem(descriptor, bean);
          getJMenu().add(item);
        }
        else if (descriptor.getPropertyType().equals(double.class))
        {
          double value = prefs.getDouble(descriptor.getName(),
              (Double) _readProperty(descriptor, bean));
          try
          {
            _writeProperty(descriptor, value, bean);
          }
          catch (Exception e)
          { /*ignore*/ }
          Component item = _getDoubleChooser(descriptor, bean);
          getJToolBar().add(item);
        }
        else if (descriptor.getPropertyType().equals(int.class))
        {
          int value = prefs.getInt(descriptor.getName(),
              (Integer) _readProperty(descriptor, bean));
          try
          {
            _writeProperty(descriptor, value, bean);
          }
          catch (Exception e)
          { /*ignore*/ }
          Component item = _getIntChooser(descriptor, bean);
          getJToolBar().add(item);
        }
        else
        {
          // assert( false ) : "No Editor for Property of type " +
          // descriptor.getPropertyType();
        }

      }

      jLabel.setText(_getBeanInfo(_beanClass).getBeanDescriptor().getName());
    }
  }

  /**
   * reads the given Property.
   * 
   * @param descriptor
   *          the Descriptor for the Property to read
   * @return Object The Value of the property.
   */
  private Object _readProperty(PropertyDescriptor descriptor, Object bean)
  {
    assert (bean != null);
    Object value = null;
    try
    {
      value = descriptor.getReadMethod().invoke(bean, (Object[]) null);
    }
    catch (IllegalArgumentException e)
    {
      System.out.println(e.getMessage());
      e.printStackTrace();
    }
    catch (Exception e)
    {
      // XXX handle ClassCastException
      System.out.println(e.getClass());
      System.out.println(e.getMessage());
      e.printStackTrace();
    }
    return value;
  }

  /** writes the given property */
  private void _writeProperty(PropertyDescriptor desc, Object value, Object bean)
  throws IllegalArgumentException, Exception
  {
    Method setter = desc.getWriteMethod();
    Object[] args = { value };
    desc.getWriteMethod().invoke(bean, args);
  }

  /**
   * gets the BeanInfo object.
   * 
   * @param cls
   * @return
   */
  private BeanInfo _getBeanInfo(Class cls)
  {
    BeanInfo beaninfo = null;

    try
    {
      beaninfo = Introspector.getBeanInfo(cls);
    }
    catch (Exception e)
    {
      // XXX: handle this better
      System.out.println(e.getMessage());
    }

    return beaninfo;
  }

  /**
   * Gets the PropertyDescriptors for the _bean.
   * 
   * @return PropertyDescriptor[]
   */
  private PropertyDescriptor[] _getPropertyDescriptors(BeanInfo info)
  {
    assert (info != null);

    PropertyDescriptor[] desc = info.getPropertyDescriptors();
    ArrayList<PropertyDescriptor> list = new ArrayList<PropertyDescriptor>();

    for (PropertyDescriptor description : desc)
    {
      Method reader = description.getReadMethod();
      if (reader != null)
      {
        list.add(description);
      }
    }

    return (PropertyDescriptor[]) list.toArray(new PropertyDescriptor[list
        .size()]);
  }

  public Object[] getBean()
  {
    return _beans;
  }

  /**
   * This method initializes jToolBar
   * 
   * @return javax.swing.JToolBar
   */
  private JToolBar getJToolBar()
  {
    if (jToolBar == null)
    {
      jToolBar = new JToolBar();
      jToolBar.setFloatable(false);
      jToolBar.add(getJMenuBar());
    }
    return jToolBar;
  }

  private JMenuBar jMenuBar;

  /**
   * @return
   */
  private JMenuBar getJMenuBar()
  {
    if (jMenuBar == null)
    {
      jMenuBar = new JMenuBar();
      jMenuBar.add(getJMenu());
      jMenuBar.setBorder(null);
    }
    return jMenuBar;
  }

  /**
   * This method initializes jMenu
   * 
   * @return javax.swing.JMenu
   */
  private JMenu getJMenu()
  {
    if (jMenu == null)
    {
      jMenu = new JMenu();
      jMenu.setText("settings");
    }
    return jMenu;
  }

  /** returns a CheckBox MenuItem for the given Property */
  private JCheckBoxMenuItem _getCheckBoxItem(
      final PropertyDescriptor descriptor, final Object bean)
  {
    final JCheckBoxMenuItem item = new JCheckBoxMenuItem(descriptor.getName());
    item.setState(((Boolean) (_readProperty(descriptor, bean))).booleanValue());
    item.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent arg0)
      {
        try 
        {
          _writeProperty(descriptor, item.getState(), bean);
          Preferences prefs = Preferences.userNodeForPackage(_beanClass);
          prefs.putBoolean(descriptor.getName(), item.getState());
        }
        catch (Exception e)
        {
          item.setState(!item.getState());
        }
      }
    });

    return item;
  }

  /** returns a editable combobox with filled default values */
  private Component _getDoubleChooser(final PropertyDescriptor descriptor,
      final Object bean)
  {
    JComboBox combobox = new JComboBox();
    combobox.setEditable(true);

    Font font = new Font("Verdana", 8, 10);
    combobox.setBorder(BorderFactory.createTitledBorder(combobox.getBorder(),
        descriptor.getName(), TitledBorder.LEFT, TitledBorder.LEFT, font));

    double value = ((Double) _readProperty(descriptor, bean)).doubleValue();
    for (int i = 0; i < 10; i++)
    {
      combobox.addItem(value * (1 << i));
    }

    combobox.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e)
      {
        JComboBox cb = (JComboBox) e.getSource();
        Object value = cb.getSelectedItem();
        try
        {
          _writeProperty(descriptor, value, bean);
          cb.setBackground(UIManager.getColor("Combobox.background"));
          Preferences prefs = Preferences.userNodeForPackage(_beanClass);
          prefs.putDouble(descriptor.getName(), ((Double) value).doubleValue());
        }
        catch (Exception e1)
        {
          cb.setBackground(Color.RED);
        }
      }
    });

    combobox.setPreferredSize(new Dimension(100, 40));

    return combobox;
  }

  /** returns a editable combobox with filled default values */
  private Component _getIntChooser(final PropertyDescriptor descriptor,
      final Object bean)
  {
    JComboBox combobox = new JComboBox();
    combobox.setEditable(true);

    Font font = new Font("Verdana", 8, 10);
    combobox.setBorder(BorderFactory.createTitledBorder(combobox.getBorder(),
        descriptor.getName(), TitledBorder.LEFT, TitledBorder.LEFT, font));

    int value = ((Integer) _readProperty(descriptor, bean)).intValue();
    for (int i = 0; i < 10; i++)
    {
      combobox.addItem(value * (1 << i));
    }

    combobox.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e)
      {
        JComboBox cb = (JComboBox) e.getSource();
        Object value = cb.getSelectedItem();
        try
        {
          _writeProperty(descriptor, value, bean);
          cb.setBackground(UIManager.getColor("Combobox.background"));
          Preferences prefs = Preferences.userNodeForPackage(_beanClass);
          prefs.putInt(descriptor.getName(), ((Integer) value).intValue());
        }
        catch (Exception e1)
        {
          cb.setBackground(Color.RED);
        }
      }
    });

    combobox.setPreferredSize(new Dimension(100, 40));

    return combobox;
  }

  /**
   * sets a single Object to be used
   * 
   * @param bean
   *          the bean to set
   */
  public void setBean(Object bean)
  {
    setBeans(new Object[] { bean });
  }
} // @jve:decl-index=0:visual-constraint="72,63"
